@@ -16,8 +16,10 @@ from .core import (
     load_into_instance,
 )
 from .dump import asdict, asjson, astoml, asyaml
+from .loaders import register_loader as loader
 from .postpone import postpone
 from .singleton import Singleton, SingletonMeta
+from .type_converters import register_converter as converter
 
 __all__ = [
     # cls
@@ -43,4 +45,7 @@ __all__ = [
     "astoml",
     "asyaml",
     "asjson",
+    # register
+    "loader",
+    "converter",
 ]
