@@ -21,6 +21,7 @@ from .errors import (
 )
 from .helpers import camel_to_snake
 from .postpone import Postponed
+from .type_converters import CONVERTERS
 
 # T is a reusable typevar
 T = typing.TypeVar("T")
@@ -72,8 +73,7 @@ def __load_data(
     if isinstance(data, Path):
         with data.open("rb") as f:
             loader = loaders.get(data.suffix or data.name)
-            data = loader(f)
-
+            data = loader(f, data.resolve())
     if not data:
         return {}
 
@@ -131,39 +131,13 @@ def check_type(value: typing.Any, expected_type: T_typelike) -> bool:
 F = typing.TypeVar("F")
 
 
-def str_to_bool(value: str) -> bool:
-    """
-    Used by convert_between, usually for .env loads.
-
-    Example:
-        SOME_VALUE=TRUE -> True
-        SOME_VALUE=1 -> True
-        SOME_VALUE=Yes -> True
-
-        SOME_VALUE  -> None
-        SOME_VALUE=NOpe -> False
-
-        SOME_VALUE=Unrelated -> Error
-    """
-    if not value:
-        return False
-
-    first_letter = value[0].lower()
-    # yes, true, 1
-    if first_letter in {"y", "t", "1"}:
-        return True
-    elif first_letter in {"n", "f", "0"}:
-        return False
-    else:
-        raise ValueError("Not booly.")
-
-
 def convert_between(from_value: F, from_type: typing.Type[F], to_type: type[T]) -> T:
     """
     Convert a value between types.
     """
-    if from_type is str and to_type is bool:
-        return str_to_bool(from_value)  # type: ignore
+    if converter := CONVERTERS.get((from_type, to_type)):
+        return typing.cast(T, converter(from_value))
+
     # default: just convert type:
     return to_type(from_value)  # type: ignore
 
@@ -318,7 +292,9 @@ def dataclass_field(cls: Type, key: str) -> typing.Optional[dc.Field[typing.Any]
     return fields.get(key)
 
 
-def load_recursive(cls: Type, data: dict[str, T], annotations: dict[str, Type]) -> dict[str, T]:
+def load_recursive(
+    cls: Type, data: dict[str, T], annotations: dict[str, Type], convert_types: bool = False
+) -> dict[str, T]:
     """
     For all annotations (recursively gathered from parents with `all_annotations`), \
     try to resolve the tree of annotations.
@@ -359,19 +335,22 @@ def load_recursive(cls: Type, data: dict[str, T], annotations: dict[str, Type])
                 arguments = typing.get_args(_type)
                 if origin is list and arguments and is_custom_class(arguments[0]):
                     subtype = arguments[0]
-                    value = [_load_into_recurse(subtype, subvalue) for subvalue in value]
+                    value = [_load_into_recurse(subtype, subvalue, convert_types=convert_types) for subvalue in value]
 
                 elif origin is dict and arguments and is_custom_class(arguments[1]):
                     # e.g. dict[str, Point]
                     subkeytype, subvaluetype = arguments
                     # subkey(type) is not a custom class, so don't try to convert it:
-                    value = {subkey: _load_into_recurse(subvaluetype, subvalue) for subkey, subvalue in value.items()}
+                    value = {
+                        subkey: _load_into_recurse(subvaluetype, subvalue, convert_types=convert_types)
+                        for subkey, subvalue in value.items()
+                    }
                 # elif origin is dict:
                 # keep data the same
                 elif origin is typing.Union and arguments:
                     for arg in arguments:
                         if is_custom_class(arg):
-                            value = _load_into_recurse(arg, value)
+                            value = _load_into_recurse(arg, value, convert_types=convert_types)
                         else:
                             # print(_type, arg, value)
                             ...
@@ -385,6 +364,7 @@ def load_recursive(cls: Type, data: dict[str, T], annotations: dict[str, Type])
                     # actually just passing _type as first arg!
                     typing.cast(Type_C[typing.Any], _type),
                     value,
+                    convert_types=convert_types,
                 )
 
         elif _key in cls.__dict__:
@@ -443,7 +423,7 @@ def check_and_convert_data(
     annotations = all_annotations(cls, _except=_except)
 
     to_load = convert_config(data)
-    to_load = load_recursive(cls, to_load, annotations)
+    to_load = load_recursive(cls, to_load, annotations, convert_types=convert_types)
     if strict:
         to_load = ensure_types(to_load, annotations, convert_types=convert_types)
 
