@@ -2,24 +2,9 @@
 Loads loaders based on Python version.
 """
 
-import typing
-
-from ._types import T_config
-
 # tomli used for every Python version now.
-from .loaders_shared import dotenv, json, toml, yaml
-
-__all__ = ["get", "toml", "json", "yaml", "dotenv"]
-
-T_loader = typing.Callable[[typing.BinaryIO], T_config]
-
-LOADERS: dict[str, T_loader] = {
-    "toml": toml,
-    "json": json,
-    "yml": yaml,
-    "yaml": yaml,
-    "env": dotenv,
-}
+from .loaders_shared import dotenv, ini, json, toml, yaml
+from .register import LOADERS, T_loader, register_loader
 
 
 def get(extension: str) -> T_loader:
@@ -27,7 +12,11 @@ def get(extension: str) -> T_loader:
     Get the right loader for a specific extension.
     """
     extension = extension.removeprefix(".")
+
     if loader := LOADERS.get(extension):
         return loader
     else:
         raise ValueError(f"Invalid extension {extension}")
+
+
+__all__ = ["get", "toml", "json", "yaml", "dotenv", "ini", "register_loader"]
